#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QMainWindow>
#include <QThread>
namespace Ui {
    class Speedo;
}

class Speedo : public QMainWindow {
    Q_OBJECT
public:
    Speedo(QWidget *parent = 0);
    ~Speedo();
    Ui::Speedo *ui;
    int unit;
    int hour,min,sec,tensofsec;
    int started,paused;
    int display; // 0 speed, 1-trip, 2-total

protected:
    void changeEvent(QEvent *e);


private slots:
    void on_pushButton_3_clicked();
    void on_pauseTimeButton_clicked();
    void on_startTimeButton_clicked();
    void on_pushButton_2_clicked();
    void on_pushButton_clicked();
public slots:
    void start_gps();
    void updateLocation();
    void updateTime();
};


#endif // MAINWINDOW_H
